@@ -1,21 +1,17 @@
 import hashlib
+import warnings
+
 import cryptography
 from cryptography import x509
-from cryptography.hazmat.primitives.asymmetric import rsa, dsa, ec, dh
-from cryptography.hazmat.primitives.asymmetric import ed25519, x25519
-from cryptography.hazmat.primitives.asymmetric import x448, ed448
 from cryptography.hazmat.primitives import serialization
+from cryptography.hazmat.primitives.asymmetric import dh, dsa, ec, ed448, ed25519, rsa, x448, x25519
 
-from .rsakeys import fermat
-from .rsakeys import pattern
-from .rsakeys import roca
-from .rsakeys import rsainvalid
-from .rsakeys import sharedprimes
-from .rsakeys import smallfactors
 from .allkeys import blocklist
+from .rsakeys import (fermat, pattern, roca, rsainvalid, rsawarnings, sharedprimes, smallfactors,
+                      xzbackdoor)
 
 # List of available checks
-allchecks = {
+defaultchecks = {
     "fermat": {
         "type": "rsa",
         "function": fermat,
@@ -46,6 +42,11 @@ allchecks = {
         "function": smallfactors,
         "desc": "Small prime factors (<=65537, usually corrupt)",
     },
+    "xzbackdoor": {
+        "type": "rsa",
+        "function": xzbackdoor,
+        "desc": "xz backdoor payload in RSA n",
+    },
     "blocklist": {
         "type": "all",
         "function": blocklist,
@@ -53,6 +54,24 @@ allchecks = {
     },
 }
 
+warningchecks = {
+    "rsawarnings": {
+        "type": "rsa",
+        "function": rsawarnings,
+        "desc": "RSA key size and exponent warnings",
+    },
+}
+
+allchecks = defaultchecks | warningchecks
+
+# cryptography warns about SSH DSA keys being deprecated.
+# For now, disable the warnings. Needs a better long-term solution.
+warnings.filterwarnings(
+    "ignore",
+    category=cryptography.utils.CryptographyDeprecationWarning,
+    module="badkeys.checks",
+)
+
 
 def _checkkey(key, checks):
     r = {}
@@ -64,6 +83,10 @@ def _checkkey(key, checks):
         r["results"] = checkrsa(r["n"], e=r["e"], checks=checks)
     elif isinstance(key, ec.EllipticCurvePublicKey):
         r["type"] = "ec"
+        r["curve"] = key.curve.name
+        # shorter names for standard curves
+        if r["curve"].startswith("sec") and r["curve"].endswith("r1"):
+            r["curve"] = r["curve"][3:-2]
         r["x"] = key.public_numbers().x
         r["y"] = key.public_numbers().y
         r["results"] = checkall(r["x"], checks=checks)
@@ -72,13 +95,17 @@ def _checkkey(key, checks):
         r["y"] = key.public_numbers().y
         r["bits"] = key.key_size
         r["results"] = checkall(r["y"], checks=checks)
-    elif (
-        isinstance(key, ed25519.Ed25519PublicKey)
-        or isinstance(key, x25519.X25519PublicKey)
-        or isinstance(key, x448.X448PublicKey)
-        or isinstance(key, ed448.Ed448PublicKey)
+    elif isinstance(
+        key,
+        (
+            ed25519.Ed25519PublicKey,
+            x25519.X25519PublicKey,
+            x448.X448PublicKey,
+            ed448.Ed448PublicKey,
+        ),
     ):
         r["type"] = "ec"
+        r["curve"] = str(type(key).__name__).lower()[:-9]
         # For Ed25519 the raw key is the x coordinate
         x_b = key.public_bytes(
             encoding=serialization.Encoding.Raw,
@@ -106,7 +133,7 @@ def _checkkey(key, checks):
     return r
 
 
-def checkrsa(n, e=65537, checks=allchecks.keys()):
+def checkrsa(n, e=65537, checks=defaultchecks.keys()):
     results = {}
     for check in checks:
         callcheck = allchecks[check]["function"]
@@ -121,7 +148,7 @@ def checkrsa(n, e=65537, checks=allchecks.keys()):
     return results
 
 
-def checkall(x, checks=allchecks.keys()):
+def checkall(x, checks=defaultchecks.keys()):
     results = {}
     for check in checks:
         if allchecks[check]["type"] != "all":
@@ -133,7 +160,7 @@ def checkall(x, checks=allchecks.keys()):
     return results
 
 
-def checkpubkey(rawkey, checks=allchecks.keys()):
+def checkpubkey(rawkey, checks=defaultchecks.keys()):
     try:
         key = serialization.load_pem_public_key(rawkey.encode())
     except ValueError:
@@ -142,7 +169,7 @@ def checkpubkey(rawkey, checks=allchecks.keys()):
     return _checkkey(key, checks)
 
 
-def checkprivkey(rawkey, checks=allchecks.keys()):
+def checkprivkey(rawkey, checks=defaultchecks.keys()):
     try:
         priv = serialization.load_pem_private_key(rawkey.encode(), password=None)
     except ValueError:
@@ -157,7 +184,7 @@ def checkprivkey(rawkey, checks=allchecks.keys()):
     return _checkkey(priv.public_key(), checks)
 
 
-def checkcrt(rawcert, checks=allchecks.keys()):
+def checkcrt(rawcert, checks=defaultchecks.keys()):
     try:
         crt = x509.load_pem_x509_certificate(rawcert.encode())
     except (ValueError, cryptography.x509.base.InvalidVersion):
@@ -172,12 +199,27 @@ def checkcrt(rawcert, checks=allchecks.keys()):
         return {"type": "unsupported", "results": {}}
 
 
-def checkcsr(rawcsr, checks=allchecks.keys()):
-    csr = x509.load_pem_x509_csr(rawcsr.encode())
+def checkcsr(rawcsr, checks=defaultchecks.keys()):
+    try:
+        csr = x509.load_pem_x509_csr(rawcsr.encode())
+    except ValueError:
+        return {"type": "unparseable", "results": {}}
     return _checkkey(csr.public_key(), checks)
 
 
-def checksshpubkey(sshkey, checks=allchecks.keys()):
+def checksshprivkey(sshkey, checks=defaultchecks.keys()):
+    try:
+        pkey = serialization.load_ssh_private_key(sshkey.encode(), password=None)
+    except ValueError:
+        # happens e.g. on password-protected keys
+        return {"type": "unsupported", "results": {}}
+    except cryptography.exceptions.UnsupportedAlgorithm:
+        # happens e.g. on pre-standard sk-ssh-ed25519@openssh.com keys
+        return {"type": "unsupported", "results": {}}
+    return _checkkey(pkey.public_key(), checks)
+
+
+def checksshpubkey(sshkey, checks=defaultchecks.keys()):
     try:
         pkey = serialization.load_ssh_public_key(sshkey.encode())
     except ValueError:
@@ -189,24 +231,25 @@ def checksshpubkey(sshkey, checks=allchecks.keys()):
     return _checkkey(pkey, checks)
 
 
-def detectandcheck(inkey, checks=allchecks.keys()):
+def detectandcheck(inkey, checks=defaultchecks.keys()):
     if "-----BEGIN CERTIFICATE-----" in inkey:
         return checkcrt(inkey, checks)
-    elif "-----BEGIN CERTIFICATE REQUEST-----" in inkey:
+    if "-----BEGIN CERTIFICATE REQUEST-----" in inkey:
         return checkcsr(inkey, checks)
-    elif "-----BEGIN PUBLIC KEY-----" in inkey:
+    if "-----BEGIN PUBLIC KEY-----" in inkey:
         return checkpubkey(inkey, checks)
-    elif "-----BEGIN RSA PUBLIC KEY-----" in inkey:
+    if "-----BEGIN RSA PUBLIC KEY-----" in inkey:
         return checkpubkey(inkey, checks)
-    elif "-----BEGIN PRIVATE KEY-----" in inkey:
+    if "-----BEGIN PRIVATE KEY-----" in inkey:
         return checkprivkey(inkey, checks)
-    elif "-----BEGIN RSA PRIVATE KEY-----" in inkey:
+    if "-----BEGIN RSA PRIVATE KEY-----" in inkey:
         return checkprivkey(inkey, checks)
-    elif "-----BEGIN DSA PRIVATE KEY-----" in inkey:
+    if "-----BEGIN DSA PRIVATE KEY-----" in inkey:
         return checkprivkey(inkey, checks)
-    elif "-----BEGIN EC PRIVATE KEY-----" in inkey:
+    if "-----BEGIN EC PRIVATE KEY-----" in inkey:
         return checkprivkey(inkey, checks)
-    elif inkey.startswith("ssh-") or inkey.startswith("ecdsa-"):
+    if "-----BEGIN OPENSSH PRIVATE KEY-----" in inkey:
+        return checksshprivkey(inkey, checks)
+    if inkey.startswith(("ssh-", "ecdsa-")):
         return checksshpubkey(inkey, checks)
-    else:
-        return {"type": "notfound", "results": {}}
+    return {"type": "notfound", "results": {}}
