@@ -14,10 +14,12 @@ class TestBlocklist(unittest.TestCase):
             key = f.read()
         r = badkeys.checkpubkey(key, checks=["blocklist"])
         self.assertTrue("blocklist" in r["results"])
+        self.assertTrue(r["bits"] == 2048)
         with open(f"{TDPATH}rsa-ok.key") as f:
             key = f.read()
         r = badkeys.checkpubkey(key, checks=["blocklist"])
         self.assertFalse(r["results"])
+        self.assertTrue(r["bits"] == 2048)
 
     @unittest.skipUnless(os.environ.get("RUN_ONLINETESTS"), "Skipping blocklist tests")
     def test_ecbl(self):
@@ -25,14 +27,17 @@ class TestBlocklist(unittest.TestCase):
             key = f.read()
         r = badkeys.checkpubkey(key, checks=["blocklist"])
         self.assertTrue("blocklist" in r["results"])
+        self.assertTrue(r["curve"] == "p256")
         with open(f"{TDPATH}ed25519-rfc-example.key") as f:
             key = f.read()
         r = badkeys.checkpubkey(key, checks=["blocklist"])
         self.assertTrue("blocklist" in r["results"])
+        self.assertTrue(r["curve"] == "ed25519")
         with open(f"{TDPATH}x448-ok.key") as f:
             key = f.read()
         r = badkeys.checkpubkey(key, checks=["blocklist"])
         self.assertFalse(r["results"])
+        self.assertTrue(r["curve"] == "x448")
 
     # Testing key in SSH DSA pubkey format.
     # Python cryptography plans to deprecate this format,
@@ -43,6 +48,7 @@ class TestBlocklist(unittest.TestCase):
             key = f.read()
         r = badkeys.checksshpubkey(key, checks=["blocklist"])
         self.assertTrue("blocklist" in r["results"])
+        self.assertTrue(r["bits"] == 1024)
 
 
 if __name__ == "__main__":
